Task: InsuranceQA
==================
Description: Task which requires agents to identify high quality answers composed by professionals with deep domain knowledge. From Feng et al. '15. 

Link: https://arxiv.org/abs/1508.01585

Tags: #InsuranceQA, #All, #QA

